@@ -1,8 +1,8 @@
 "use strict";
 
-var EventEmitter = require("events");
+var ee = require("event-emitter");
 
-var referee = new EventEmitter();
+var referee = ee();
 
 // construct the public API
 referee.add = require("./create-add")(referee);
